#############################################################################
##
#W    complexes.gd        share package 'homology'     Heckenbach, Welker
##
## Some example complexes and constructors for simplicial complexes.

#==================================================
# Example simplicial complexes
#==================================================

#############################################################################
##
#F  SCSphere( <n> )
##
##  constructs a simplicial complex representing the <n>-sphere, $n \geq -1$. 
##
DeclareGlobalFunction ("SCSphere");

#############################################################################
##
#V  SCMobiusStrip, SCTorus, SCKleinBottle
##
##  simplicial complexes representing the Mobius strip, torus, Klein bottle.
##
DeclareGlobalVariable ("SCMobiusStrip");
DeclareGlobalVariable ("SCTorus");
DeclareGlobalVariable ("SCKleinBottle");

#############################################################################
##
#F  SCChessboard( <m>, <n> )
##
##  constructs a simplicial complex representing the <m> by <n> chessboard
##  complex, where <m> and <n> are positive integers.  See \cite{??} for
##  details.  The facets have dimension min(m,n) - 1.  
##  For example, when $m \geq n$, The chessboard complex has $m!/(m-n)!$ facets.
##
DeclareGlobalFunction ("SCChessboard");

#############################################################################
##
#F  SCMatching( <m> )
##
##  constructs a simplicial complex representing the <m> vertices matching
##  complex, where <m> is a positive integers.  See \cite{??} for
##  details.  The facets have dimension [m/2] - 1.
##
DeclareGlobalFunction ("SCMatching");

#############################################################################
##
#F  SCGeneralizedKleinBottle( <n> )
##
##  constructs a simplicial complex which is a generalization of a Klein
##  bottle.  Where the Klein bottle has 2-torsion, GeneralizedKleinBottle(`<n>')
##  has `<n>'-torsion, for $n \geq 2$.
##
DeclareGlobalFunction ("SCGeneralizedKleinBottle");

#############################################################################
##
#F  SCNot2ConnectedGraphs( <n> )
##
##  constructs a simplicial complex whose facets are in 1-1 correspondence
##  with the set of all not-2-connected graphs, for $n \geq 3$.  
##  Each facet corresponds to the set of edges of such a graph.  The complex 
##  has $n(2^{n-2} - 1)$ facets.  See \cite{??} for further intformation.
##
DeclareGlobalFunction ("SCNot2ConnectedGraphs");

#==================================================
# Operations on simplicial complexes
#==================================================


#############################################################################
##
#F  SCWedge( [<simplicial complex>, ..] )
##
##  constructs a simplicial complex representing the wedge product of the 
##  complexes in the argument list.
##
DeclareGlobalFunction ("SCWedge");

#############################################################################
##
#F  SCJoin( <sc1>, <sc2> )
##
##  constructs a simplicial complex representing the join of simplicial
##  complexes `<sc1>' and `<sc1>'.
##
DeclareGlobalFunction ("SCJoin");

#############################################################################
##
#F  SCCone( <sc> )
##
##  constructs a simplicial complex representing the cone over `<sc>'.
##
DeclareGlobalFunction ("SCCone");

#############################################################################
##
#F  SCSuspension( <sc> )
##
##  constructs the suspension over `<sc>'.  See for example \cite{Muncres} 
##  for definitions of wedge, join, cone, suspension.
##
DeclareGlobalFunction ("SCSuspension");


#############################################################################
##
#F  SCStar ( <complex>, <face> ) 
##
##  constructs the star of the face <face> in the simplicial complex <complex>
##
DeclareGlobalFunction ("SCStar");

#############################################################################
##
#F  SCLink ( <complex>, <face> ) 
##
##  constructs the link of the face <face> in the simplicial complex <complex>
##
DeclareGlobalFunction ("SCLink");

#############################################################################
##
#F  SCCompactify ( <complex> ) 
##
##  Eliminates non-maximal faces from <complex> 
##
DeclareGlobalFunction ("SCCompactify");

#############################################################################
##
#F  SCRestriction ( <complex>, <face> ) 
##
##  constructs the restriction of the simplicial complex <complex>
##  to the set <face>
##
DeclareGlobalFunction ("SCRestriction");

#############################################################################
##
#F  SCAlexanderDual ( <complex> ) 
##
##  constructs the combinatorial Alexander dual of the simplicial complex
##  <complex>
##
DeclareGlobalFunction ("SCAlexanderDual");

#############################################################################
##
#F  SCDeletedJoin ( <complex1>, <complex2> ) 
##
##  constructs the deleted join of the simplicial complexes <complex1>
##  and <complex2> 
##
DeclareGlobalFunction ("SCDeletedJoin");

#############################################################################
##
#F  SCDimension ( <complex> ) 
##
##  calculates the dimension of the simplicial complex <complex>
##
DeclareGlobalFunction ("SCDimension");

#############################################################################
##
#F  SCMinimalNonFaces ( <complex> ) 
##
##  constructs the list of minimal non-faces of the simplicial complex
##  <complex>
##
DeclareGlobalFunction ("SCMinimalNonFaces");

